/**
 * @file version.h
 * @author Radek Krejci <rkrejci@cesnet.cz>
 * @author Michal Vasko <mvasko@cesnet.cz>
 * @brief libyang version definitions
 *
 * Copyright (c) 2020 - 2024 CESNET, z.s.p.o.
 *
 * This source code is licensed under BSD 3-Clause License (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://opensource.org/licenses/BSD-3-Clause
 */

#ifndef LY_VERSION_H_
#define LY_VERSION_H_

#ifdef __cplusplus
extern "C" {
#endif

#define LY_VERSION_MAJOR 3 /**< libyang major version number */
#define LY_VERSION_MINOR 2 /**< libyang minor version number */
#define LY_VERSION_MICRO 0 /**< libyang micro version number */
#define LY_VERSION "3.2.0" /**< libyang version string */

#define LY_PROJ_VERSION_MAJOR 3 /**< project major version number */
#define LY_PROJ_VERSION_MINOR 1 /**< project minor version number */
#define LY_PROJ_VERSION_MICRO 0 /**< project micro version number */
#define LY_PROJ_VERSION "3.1.0" /**< project version string */

struct ly_version {
    uint32_t major; /**< Major version number */
    uint32_t minor; /**< Minor version number */
    uint32_t micro; /**< Micro version number */
    const char *str; /**< Version string */
};

/**
 * @brief libyang SO version.
 */
LIBYANG_API_DECL extern struct ly_version ly_version_so;

/**
 * @brief libyang project version.
 */
LIBYANG_API_DECL extern struct ly_version ly_version_proj;

#ifdef __cplusplus
}
#endif

#endif /* LY_VERSION_H_ */
